
import os


def load_flag(name):
    return os.environ.get(name, "").lower() not in ("0", "no", "off", "false")


def load_list(name, default=None):
    try:
        return [each.strip() for each in os.environ[name].split(",")]
    except KeyError:
        return default


DEFAULT_MODULES = [
    "dndbuddy_basic",
    "dndbuddy_phb",
]

ANSI_COLORS = load_flag("DND_ANSI_COLORS")
TRY_PAGER = load_flag("DND_TRY_PAGER")
MODULE_NAMES = load_list("DND_MODULES", DEFAULT_MODULES)




import re

from dndbuddy_core import command


ADV = "ADV."
DIS = "DIS."

DC = "D.C."
MOD = "mod"
BONUS = "bonus"

PRO = "PRO"

STR = "STR"
DEX = "DEX"
CON = "CON"
INT = "INT"
WIS = "WIS"
CHA = "CHA"

ATK = "ATK"
DMG = "DMG"
SPEED = "SPEED"


REGEX = r"^terms?$"

TEXT = """\
Terms
=====
    ADV. = Advantage
           Roll twice, take the higher total
    DIS. = Disadvantage
           Roll twice, take the lower total

    D.C. = Difficulty Class
           Number to beat with an ability check

    mod = Modifier
          The +/- number associated with a stat/skill

    PRO = Proficiency
          ...

    STR = Strength
    DEX = Dexterity
    CON = Constitution
    INT = Intelligence
    WIS = Wisdom
    CHA = Charisma

    ATK = Attack
    DMG = Damage
"""


class TermsCommand(command.Command):

    HELP = "index of terms (try `terms`)"

    @staticmethod
    def match(inp):
        return re.match(REGEX, inp)

    @staticmethod
    def run(inp):
        print(TEXT)




from dndbuddy_core import settings


def _color(string, ansi, bold=False):
    """Colors the given string with the given ANSI color index."""
    return "\x1b[1;{}m{}\x1b[0m".format(ansi, string)


def _color_wrap(string, ansi, bold=False):
    if settings.ANSI_COLORS:
        return _color(string, ansi, bold=bold)
    return string


def green(string, bold=False):
    return _color_wrap(string, 32, bold=bold)


def yellow(string, bold=False):
    return _color_wrap(string, 33, bold=bold)


def red(string, bold=False):
    return _color_wrap(string, 31, bold=bold)


def white(string, bold=False):
    return _color_wrap(string, 39, bold=bold)




import subprocess
import tempfile

from dndbuddy_core import settings


def paged(text):
    """
    Source: https://chase-seibert.github.io/blog/2012/10/31/python-fork-exec-vim-raw-input.html#
    """
    if not settings.TRY_PAGER:
        print(text)
        return

    try:
        with tempfile.NamedTemporaryFile("w") as f:
            f.write(text)
            f.flush()
            p = subprocess.Popen(["/usr/bin/less", f.name])
            p.wait()
    except KeyboardInterrupt:
        pass




import abc


class Command(abc.ABC):
    """Abstract class to standardize commands"""

    @classmethod
    def __call__(cls, inp):
        """Returns whether given input ran this command"""
        match = cls.match(inp)
        if match:
            cls.run(inp)
        return match

    @abc.abstractstaticmethod
    def match(inp):
        """Returns whether given input matches this command"""
        pass

    @abc.abstractstaticmethod
    def run(inp):
        """Runs this command with the given input"""
        pass



"""
PyPI setup file
"""

from setuptools import setup


setup(
    name='dndbuddy_core',
    packages=['dndbuddy_core'],
    version='0.0.1',
    author='Matt Cotton',
    author_email='matthewcotton.cs@gmail.com',
    url='https://github.com/MattCCS/DnDBuddy-Core',

    description='The core libraries for DnDBuddy',
    long_description=open("README.md").read(),
    classifiers=[
        "Programming Language :: Python :: 3",
    ],

    entry_points={},
)
